/* help.c -- Help screens and help-display function for Targ-Hurt ESP
             Trainer

   History: rhs 23-mar-87
*/

#include "mancon.h"
#include "declares.h"
#include <stdio.h>

IMPORT gi_fg1, gi_bg1;



#define HELP1_LINES 22
static char *help1[] =
{
"                     Using the Targ-Hurt ESP Trainer",
"",
"     You can use this program to practice clairvoyance or precognition.",
"Clairvoyance is, basically, telling something which is has already happened",
"and precognition is foretelling something which is about to happen.",
"An example of clairvoyance is when you go through a day feeling certain",
"that something dreadful has happened, to find out later that your house",
"has burned down in your absence.  An example of precognition is when you",
"go through a day feeling certain that something bad is about to happen,",
"then your house burns down that night.",
"",
"     This program will not burn your house down, but it does let you",
"practice clairvoyance and precognition with a method developed by NASA-",
"sponsored scientists.",
"",
"",
"",
"",
"",
"",
"                 Press ESC to return to main menu,",
"                 any other key to continue viewing",
};


#define HELP2_LINES 22
static char *help2[] =
{
"",
"     This program creates facts which you must either tell or foretell.",
"The facts are simple: the program randomly selects, a compass-direction,",
"north, south, east, or west.  In clairvoyance mode, the machine selects",
"the direction, then you try to tell what direction it selected.  In",
"precognition mode, you try to foretell what direction the program will",
"select-- you make your prediction, there is a delay of one, two, or",
"three seconds (you specify the delay), then the machine makes a selection",
"and shows it to you.",
"",
"     The program always shows you what ITS selection was.",
"",
"     You make your selections by pressing arrow keys: up is north, down is",
"is south, left is west, and right is east.  If your selection matches the",
"program's selection, a \"hit\" is recorded at the top of the screen.  Each",
"time you enter a guess, the number of tries is incremented.  The percentage",
"of hits to tries is displayed, and any percentage over 25% is better than",
"what you could expect from purely random guessing.",
"",
"",
"                 Press ESC to return to main menu,",
"                 any other key to continue viewing"
};


#define HELP3_LINES 22
static char *help3[] =
{
"",
"     Press P, to pass, when you do not feel sure that you know the program's",
"selection.  No \"try\" will be recorded and your score is uneffected.  The",
"program will show you what its selection was.  Try not to pass too often,",
"it distorts the measurement of your progress.",
"",
"     Pressing R resets the number of hits and tries to zero.  The original",
"Targ-Hurt machine automatically reset the score after 25 tries.  This pro-",
"gram does not reset your score, but you should reset it yourself period-",
"ically so that each hit has a greater effect on your hit percentage.",
"",
"     There are five messages which help indicate your progress: \"Traces",
"of ESP\" is displayed when you are performing a little better than chance.",
"\"ESP ability present\", \"Useful at Las Vegas\", \"Exceptional ESP ability\"",
"and \"Psychic!, Medium!, Oracle!\" are the other messages.  If you consist-",
"ently get \"Exceptional ESP ability\", you are scoring well above the pure-",
"chance level, and may wish to consider seeking professional parapsychological ",
"testing. \"Psychic! Medium! Oracle!\" only appears when your hit percent is ",
"near 60%, a truly remarkable performance.",
"",
"                 Press ESC to return to main menu,",
"                 any other key to continue viewing"
};



#define HELP4_LINES 24
static char *help4[] =
{
"History: The Targ-Hurt ESP Trainer was originally a box designed in 1966",
"         by Russell Targ, a plasma physicist, and David B. Hurt, an engineer.",
"         A short note in Electronics magazine (Dec. 26, 1966, p36) reported",
"         that Targ was working on an ESP teaching box.  The subject tries to",
"         guess which of four buttons will light up and the box \"reinforces",
"         by punishment as well as reward.\"  Five years later, with a grant",
"         from the Parapsychology Foundation (founded by the well-known spirit-",
"         ualist medium Eileen J. Garrett), Targ and Hurt designed and built",
"         a more advanced ESP teaching device.  In 1972 Targ was hired by the",
"         Electronics and Bioengineering Laboratory of the Stanford Research",
"         Institute to continue his research.  The research was made possible",
"         by a grant of $80,000 from NASA, with the Jet Propulsion Laboratory",
"         of the California Institute of Technology serving as administrator.",
"         The research concluded that the subjects of the experiments, mostly",
"         school children, failed to guess better than approximately one",
"         successful guess for every three incorrect guesses.  The research",
"         grant was not extended.",
"",
"         This version of the ESP Trainer was written by Rudy H. Smith",
"         in March, 1987.  Mr. Smith has since undergone a successful",
"         surgical procedure which removed the tongue from his cheek.",
"         While the research by Targ and Hurt was actually conducted,",
"         it remains a mystery why Mr. Smith wasted several evenings",
"         developing a computer version of this ridiculous machine."
};


/* get_esc -- Returns TRUE if user presses escape key, FALSE if not.
*/
#define ESC 27
int get_esc()
{  char ch;
   getkey(&ch); 
   if(ch==ESC)
      return(TRUE);
   else
      return(FALSE);
}


/* disp_help -- Displays help screens.
*/
void disp_help()
{
   int j;
   disp_cls();
   disp_cursor(OFF);
   for(j=0; j<HELP1_LINES; j++)
      colrprtf(1, gi_fg1, gi_bg1, "%s\n", help1[j]);
   if(get_esc()) return; 

   disp_cls();
   for(j=0; j<HELP2_LINES; j++)
      colrprtf(1, gi_fg1, gi_bg1, "%s\n", help2[j]);
   if(get_esc()) return; 

   disp_cls();
   for(j=0; j<HELP3_LINES; j++)
      colrprtf(1, gi_fg1, gi_bg1, "%s\n", help3[j]);
   if(get_esc()) return; 

   disp_cls();
   for(j=0; j<HELP4_LINES; j++)
      colrprtf(1, gi_fg1, gi_bg1, "%s\n", help4[j]);
   get_esc();
}

/* Test main */
/*
main()
{
   disp_help();
}
*/
